
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { Extensions } from 'vscode/vscode/vs/workbench/common/contributions';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import { LifecyclePhase } from 'vscode/vscode/vs/workbench/services/lifecycle/common/lifecycle';
import { UserDataSyncWorkbenchContribution } from './userDataSync.js';
import { UserDataSyncErrorCode } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync';
import { IUserDataAutoSyncService } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync.service';
import 'vscode/vscode/vs/platform/notification/common/notification';
import { INotificationService } from 'vscode/vscode/vs/platform/notification/common/notification.service';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { localize } from 'vscode/vscode/vs/nls';
import { isWeb } from 'vscode/vscode/vs/base/common/platform';
import { UserDataSyncTrigger } from './userDataSyncTrigger.js';
import { Action } from 'vscode/vscode/vs/base/common/actions';
import { IProductService } from 'vscode/vscode/vs/platform/product/common/productService.service';
import { ICommandService } from 'vscode/vscode/vs/platform/commands/common/commands.service';
import { IHostService } from 'vscode/vscode/vs/workbench/services/host/browser/host.service';
import { SHOW_SYNC_LOG_COMMAND_ID } from 'vscode/vscode/vs/workbench/services/userDataSync/common/userDataSync';
import Severity from 'vscode/vscode/vs/base/common/severity';

let UserDataSyncReportIssueContribution = class UserDataSyncReportIssueContribution extends Disposable {
    constructor(userDataAutoSyncService, notificationService, productService, commandService, hostService) {
        super();
        this.notificationService = notificationService;
        this.productService = productService;
        this.commandService = commandService;
        this.hostService = hostService;
        this._register(userDataAutoSyncService.onError(error => this.onAutoSyncError(error)));
    }
    onAutoSyncError(error) {
        switch (error.code) {
            case UserDataSyncErrorCode.LocalTooManyRequests: {
                const message = isWeb ? ( localize(
                    10593,
                    "Settings sync is suspended temporarily because the current device is making too many requests. Please reload {0} to resume.",
                    this.productService.nameLong
                ))
                    : ( localize(
                    10594,
                    "Settings sync is suspended temporarily because the current device is making too many requests. Please restart {0} to resume.",
                    this.productService.nameLong
                ));
                this.notificationService.notify({
                    severity: Severity.Error,
                    message,
                    actions: {
                        primary: [
                            ( new Action('Show Sync Logs', ( localize(10595, "Show Log")), undefined, true, () => this.commandService.executeCommand(SHOW_SYNC_LOG_COMMAND_ID))),
                            ( new Action('Restart', isWeb ? ( localize(10596, "Reload")) : ( localize(10597, "Restart")), undefined, true, () => this.hostService.restart()))
                        ]
                    }
                });
                return;
            }
            case UserDataSyncErrorCode.TooManyRequests: {
                const operationId = error.operationId ? ( localize(10598, "Operation Id: {0}", error.operationId)) : undefined;
                const message = ( localize(
                    10599,
                    "Settings sync is disabled because the current device is making too many requests. Please wait for 10 minutes and turn on sync."
                ));
                this.notificationService.notify({
                    severity: Severity.Error,
                    message: operationId ? `${message} ${operationId}` : message,
                    source: error.operationId ? ( localize(10600, "Settings Sync. Operation Id: {0}", error.operationId)) : undefined,
                    actions: {
                        primary: [
                            ( new Action('Show Sync Logs', ( localize(10595, "Show Log")), undefined, true, () => this.commandService.executeCommand(SHOW_SYNC_LOG_COMMAND_ID))),
                        ]
                    }
                });
                return;
            }
        }
    }
};
UserDataSyncReportIssueContribution = ( __decorate([
    ( __param(0, IUserDataAutoSyncService)),
    ( __param(1, INotificationService)),
    ( __param(2, IProductService)),
    ( __param(3, ICommandService)),
    ( __param(4, IHostService))
], UserDataSyncReportIssueContribution));
const workbenchRegistry = ( Registry.as(Extensions.Workbench));
workbenchRegistry.registerWorkbenchContribution(UserDataSyncWorkbenchContribution, LifecyclePhase.Restored);
workbenchRegistry.registerWorkbenchContribution(UserDataSyncTrigger, LifecyclePhase.Eventually);
workbenchRegistry.registerWorkbenchContribution(UserDataSyncReportIssueContribution, LifecyclePhase.Eventually);
